mlkit_document_scanner library

Flutter plugin bringing MLKit Document Scanner to Flutter.

Classes

MlkitDocumentScanner
This is the main plugin class. You should be able to instantiate the class, use the startDocumentScanner method to configure and start a scanner, and collect PDF scan data from the scanResults stream.
MlkitDocumentScannerPlugin
Implementation of the MlkitDocumentScanner interface.

Enums

DocumentScannerResultMode
Options on which stream should receive updates.
MlkitDocumentScannerMode
Options that the MLKit Document Scanner allows.